# `dcm2niiw`

Thin wrapper around [dcm2niix](https://github.com/rordenlab/dcm2niix) with some defaults modified.

## CLI

```shell
uv tool install dcm2niiw
dcm2niiw --help
dcm2hdr --help
```

## Python

```shell
uv init
uv add dcm2niiw
uv run python
```

```python
>>> from dcm2niiw import dcm2nii
>>> help(dcm2nii)
```
